mnlbugs <- function(Y,
                      X,   # Need default?
                      group,
                    prior=NULL,
                    priorprecision=NULL,
                      meancenter=TRUE,
                      n.chains=3,
                      n.iter=1000,
                      n.thin=10,
                      debug=TRUE) {
    

 # Required data:
# N        total number of obs 
# J        total number of random intercepts
# K        total number of chooser specific covariates
# C        total number of choices
# Y        NxC-matrix of categorical outcomes
# X        NxK matrix of chooser specific covariates
# group    N-vector of the intercept number of observation i
#
# alpha.bar
# wish.alpha    

    # Transform data

    # Mean-center covariates
    X <- as.matrix(X)
    Xmeans <- apply(X,2,mean,na.rm=TRUE)
    if (meancenter) {
        for (i in 1:ncol(X)) X[,i]<-X[,i]-mean(X[,i])
    }


    
    # Initialize BUGS
    N <- nrow(Y)
    K <- ncol(X)
    C <- ncol(Y)
    #alpha.bar <- 0

    if (!is.null(prior)) {
    
        bugs.data <- list("N", "K", "C", "Y", "X", "prior", "priorprecision")
        proc <- "mnl3prior.bug"
    } else {
        bugs.data <- list("N", "K", "C", "Y", "X")
        proc <- "mnl3.bug"
    }
    
    
    bugs.inits <- function() {
        list(alpha=rnorm(C-1),                         
             beta=matrix(rnorm(K*(C-1)),
                         nrow=K,ncol=(C-1))           
             )    
    }
    bugs.parameters <- c("alpha","beta"
                         )
    # Call BUGS
    bugs.result <- bugs(bugs.data,
                        bugs.inits,
                        bugs.parameters,
                        proc, 
                        n.chains=n.chains,
                        n.iter=n.iter,
                        n.thin=n.thin,
                        debug=debug
                        )
    
    # Add to result
    #as(bugs.result,c("latentrank","bugs"))
    bugs.result$Y <- Y
    bugs.result$X <- X
    bugs.result$Xmeans <- Xmeans
    bugs.result$meancenter <- meancenter
    # Return result                                    
    bugs.result
}
