remnlccspecbugs <- function(Y,
                            X,   # Need default?
                            Z,
                            group,
                            possible=NULL,
                            pgroup=NULL,
                            betaprior=NULL,
                            betapriorprecision=NULL,
                            gammaprior=NULL,
                            gammapriorprecision=NULL,
                            meancenter=TRUE,
                            n.chains=3,
                            n.iter=1000,
                            n.thin=10,
                            n.burnin=NULL,
                            debug=TRUE) {
    

 # Required data:
# N        total number of obs 
# J        total number of random intercepts
# K        total number of chooser specific covariates
# C        total number of choices
# Y        NxC-matrix of categorical outcomes
# X        NxK matrix of chooser specific covariates
# group    N-vector of the intercept number of observation i
#
# alpha.bar
# wish.alpha    

    # Create structural zeros lists
    # allcat, cat23, cat13, cat23
    # allcatg, cat23g, cat13g, cat23g

    allcat <- cat23 <- cat13 <- cat12 <- allcatg <- cat23g <- cat13g <- cat12g <- NULL
    for (i in 1:nrow(possible)) {
        if (sum(possible[i,])==3) {
            allcat <- c(allcat,i)
        } else {
            if (possible[i,1]==0)
                cat23 <- c(cat23,i)
            if (possible[i,2]==0)
                cat13 <- c(cat13,i)
            if (possible[i,3]==0)
                cat12 <- c(cat12,i)
        }
    }
    for (i in 1:nrow(pgroup)) {
        if (sum(pgroup[i,])==3) {
            allcatg <- c(allcatg,i)
        } else {
            if (pgroup[i,1]==0)
                cat23g <- c(cat23g,i)
            if (pgroup[i,2]==0)
                cat13g <- c(cat13g,i)
            if (pgroup[i,3]==0)
                cat12g <- c(cat12g,i)
        }
    }
    Iallcat <- length(allcat)
    Icat23 <- length(cat23)
    Icat13 <- length(cat13)
    Icat12 <- length(cat12)
    Iallcatg <- length(allcatg)
    Icat23g <- length(cat23g)
    Icat13g <- length(cat13g)
    Icat12g <- length(cat12g)
    
    
    # Transform data

    # Mean-center covariates
    X <- as.matrix(X)
    Xmeans <- apply(X,2,mean,na.rm=TRUE)
    if (meancenter) {
        for (i in 1:ncol(X)) X[,i]<-X[,i]-mean(X[,i])
    }

    Zmeans <- matrix(NA,nrow=dim(Z)[3],ncol=dim(Z)[2])
    for (j in 1:(dim(Z)[3])) {
        Zmeans[j,] <- apply(as.matrix(Z[,,j]),2,mean,na.rm=TRUE)
        if (meancenter) {
            for (i in 1:ncol(Z)) Z[,i,j] < -Z[,i,j]-mean(Z[,i,j],na.rm=TRUE)
        }
    }
    
    # Initialize BUGS
    N <- nrow(Y)
    J <- length(unique(group))
    K <- ncol(X)
    C <- ncol(Y)
    Q <- ncol(Z)
    #alpha.bar <- 0
  
    if (!is.null(betaprior)) {  
        bugs.data <- list(#"N","J",
                          "K", "Q", "C", "Y", "X", "Z", "group",
                          "allcat", "cat13", #"cat23", "cat12",
                          "allcatg", "cat13g", #"cat23g", "cat12g",
                          "Iallcat", "Icat13", #"Icat23", "Icat12",
                          "Iallcatg", "Icat13g", #"Icat23g", "Icat12g",
                          #"possible", "pgroup",
                          "betaprior", "betapriorprecision",
                          "gammaprior", "gammapriorprecision")
        proc <- "remnl3ccspecprior.bug"
    } else {
        bugs.data <- list(#"N","J",
                          "K", "Q", "C", "Y", "X", "Z", "group",
                          "allcat", "cat13", #"cat23", "cat12",
                          "allcatg", "cat13g", #"cat23g", "cat12g",
                          "Iallcat", "Icat13", #"Icat23", "Icat12",
                          "Iallcatg", "Icat13g"#, "Icat23g", "Icat12g",
                          #"possible", "pgroup"
                          )
        proc <- "remnl3ccspec.bug"
    }

 
    
    bugs.inits <- function() {
        list(alpha=matrix(rnorm(J*(C-1)),
                          nrow=J,ncol=(C-1)),
             beta=matrix(rnorm(K*(C-1)),
                         nrow=K,ncol=(C-1)),
             gamma=matrix(rnorm(Q*(C-1)),
                         nrow=Q,ncol=(C-1)),
             omegap=rnorm(C-2),
             sigma.alpha=runif(1)
             )    
    }
    parameters.to.save <- c("alpha",
                            "beta","gamma","omegap","sigma.alpha"
                         )

#stop()

    if (is.null(n.burnin))
        n.burnin <- floor(n.iter/2)
    
    # Call BUGS
    bugs.result <- bugs(data=bugs.data,
                        inits=bugs.inits,
                        parameters.to.save,
                        proc, 
                        n.chains=n.chains,
                        n.iter=n.iter,
                        n.thin=n.thin,
                        n.burnin=n.burnin,
                        debug=debug
                        )
    
    # Add to result
    #as(bugs.result,c("latentrank","bugs"))
    bugs.result$Y <- Y
    bugs.result$X <- X
    bugs.result$Z <- Z
    bugs.result$Xmeans <- Xmeans
    bugs.result$Zmeans <- Zmeans
    bugs.result$meancenter <- meancenter
    # Return result                                    
    bugs.result
}
